==> banking-branch_14.8.0.0.0-Plus1.zip: banking-branch_14.8.0.0.0-Plus1_20250419/content/banking-branch/14.8.0.0.0/instg/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-FF98B31C-76D1-4A01-A0AF-D2FF0CC1E07A"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Setup Database",
                    "href":"set-database.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Keys and Placeholders",
                            "href":"keys-and-placeholders.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.2 </span> Create User Grants",
                            "href":"create-user-grants.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Product Installation using Installer",
                    "href":"product-installation-using-installer.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">2.1 </span> Pre-requisite",
                            "href":"requisite.html"
                        },
                        {
                            "title":"<span class=\"secnum\">2.2 </span> Installer Path",
                            "href":"installer-path.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Configure Oracle Banking Branch Service Domains",
                    "href":"configure-oracle-banking-branch-service-domains.html"
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Create Data Sources",
                    "href":"create-data-sources.html"
                },
                {
                    "title":"<span class=\"secnum\">5 </span> Deploy Services",
                    "href":"deploy-services.html"
                },
                {
                    "title":"<span class=\"secnum\">6 </span> Setup Oracle Banking Branch Kafka",
                    "href":"set-oracle-banking-branch-kafka.html"
                },
                {
                    "title":"<span class=\"secnum\">7 </span> Configure FOP",
                    "href":"configure-fop.html"
                },
                {
                    "title":"<span class=\"secnum\">8 </span> Configure SSL",
                    "href":"configure-ssl.html"
                },
                {
                    "title":"<span class=\"secnum\">9 </span> Restart and Refresh",
                    "href":"restart-and-refresh.html"
                },
                {
                    "title":"<span class=\"secnum\">10 </span> Logging Area",
                    "href":"logging-area.html"
                },
                {
                    "title":"<span class=\"secnum\">11 </span> Configure Oracle Banking Branch UI Domain and Cluster",
                    "href":"configure-oracle-banking-branch-ui-domain-and-cluster.html"
                },
                {
                    "title":"<span class=\"secnum\">12 </span> Deploy Oracle Banking Branch Processes",
                    "href":"deploy-oracle-banking-branch-processes.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">12.1 </span> Oracle Banking Branch Processes",
                            "href":"oracle-banking-branch-processes.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">13 </span> Launch Oracle Banking Branch from FLEXCUBE Universal Banking",
                    "href":"launch-oracle-banking-branch-flexcube-universal-banking.html"
                },
                {
                    "title":"<span class=\"secnum\">14 </span> Configure Oracle Digital Assistant",
                    "href":"configure-oracle-digital-assistant.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">14.1 </span> Configure ODA Instance",
                            "href":"configure-oda-instance.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">15 </span> Known Issues and Resolutions",
                    "href":"known-issues-and-resolutions.html"
                }
            ]
        }
    ]
});

==> banking-branch_14.8.1.0.0-Plus1.zip: banking-branch_14.8.1.0.0-Plus1_20251105/content/banking-branch/14.8.1.0.0/instg/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface1.html#GUID-FF98B31C-76D1-4A01-A0AF-D2FF0CC1E07A"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Setup Database",
                    "href":"database.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Keys and Placeholders",
                            "href":"keys-placeholders.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.2 </span> Create User Grants",
                            "href":"create-user-grants.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Product Installation using Installer",
                    "href":"product-installation-using-installer.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">2.1 </span> Pre-requisite",
                            "href":"pre-requisite.html"
                        },
                        {
                            "title":"<span class=\"secnum\">2.2 </span> Installer Path",
                            "href":"installer-path.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Configure Oracle Banking Branch Service Domains",
                    "href":"configure-oracle-banking-branch-service-domains.html"
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Create Data Sources",
                    "href":"create-data-sources.html"
                },
                {
                    "title":"<span class=\"secnum\">5 </span> Deploy Services",
                    "href":"deploy-services.html"
                },
                {
                    "title":"<span class=\"secnum\">6 </span> Setup Oracle Banking Branch Kafka",
                    "href":"oracle-banking-branch-kafka.html"
                },
                {
                    "title":"<span class=\"secnum\">7 </span> Configure FOP",
                    "href":"configure-fop.html"
                },
                {
                    "title":"<span class=\"secnum\">8 </span> Configure SSL",
                    "href":"configure-ssl.html"
                },
                {
                    "title":"<span class=\"secnum\">9 </span> Restart and Refresh",
                    "href":"restart-refresh.html"
                },
                {
                    "title":"<span class=\"secnum\">10 </span> Logging Area",
                    "href":"logging-area.html"
                },
                {
                    "title":"<span class=\"secnum\">11 </span> Configure Oracle Banking Branch UI Domain and Cluster",
                    "href":"configure-oracle-banking-branch-ui-domain-cluster.html"
                },
                {
                    "title":"<span class=\"secnum\">12 </span> Deploy Oracle Banking Branch Processes",
                    "href":"deploy-oracle-banking-branch-processes.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">12.1 </span> Oracle Banking Branch Processes",
                            "href":"oracle-banking-branch-processes.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">13 </span> Launch Oracle Banking Branch from FLEXCUBE Universal Banking",
                    "href":"launch-oracle-banking-branch-from-flexcube-universal-banking.html"
                },
                {
                    "title":"<span class=\"secnum\">14 </span> Configure Oracle Digital Assistant",
                    "href":"configure-oracle-digital-assistant.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">14.1 </span> Configure ODA Instance",
                            "href":"configure-oda-instance.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">15 </span> Known Issues and Resolutions",
                    "href":"known-issues-resolutions.html"
                }
            ]
        }
    ]
});
